Package: metagenomeSeq
Title: Statistical analysis for sparse high-throughput sequencing
Version: 1.55.0
Date: 2026-04-08
Author: Joseph Nathaniel Paulson, Nathan D. Olson, Domenick J. Braccia, 
    Justin Wagner, Hisham Talukder, Mihai Pop, Hector Corrada Bravo
Maintainer: Joseph N. Paulson <josephpaulson@gmail.com>
Description: metagenomeSeq is designed to determine features (be it
    Operational Taxanomic Unit (OTU), species, etc.) that are
    differentially abundant between two or more groups of multiple
    samples. metagenomeSeq is designed to address the effects of
    both normalization and under-sampling of microbial communities
    on disease association detection and the testing of feature
    correlations.
License: Artistic-2.0
Depends: R(>= 3.0), Biobase, limma, glmnet, methods, RColorBrewer
Suggests: annotate, BiocGenerics, biomformat, knitr, gss, testthat (>=
        0.8), vegan, IHW, SparseArray
Imports: parallel, matrixStats, foreach, Matrix, gplots, graphics,
        grDevices, stats, utils, Wrench
VignetteBuilder: knitr
URL: https://github.com/nosson/metagenomeSeq/
BugReports: https://github.com/nosson/metagenomeSeq/issues
biocViews: ImmunoOncology, Classification, Clustering,
        GeneticVariability, DifferentialExpression, Microbiome,
        Metagenomics, Normalization, Visualization, MultipleComparison,
        Sequencing, Software
RoxygenNote: 7.1.0
git_url: https://git.bioconductor.org/packages/metagenomeSeq
git_branch: devel
git_last_commit: 4fee4c2
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:40:08 UTC; biocbuild
