% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mergeMRexperiments.R
\name{mergeTable}
\alias{mergeTable}
\title{Merge two tables}
\usage{
mergeTable(x, y)
}
\arguments{
\item{x}{Table 1.}

\item{y}{Table 2.}
}
\value{
Merged table
}
\description{
Merge two tables
}
