% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MRexperiment2biom.R
\name{MRexperiment2biom}
\alias{MRexperiment2biom}
\title{MRexperiment to biom objects}
\usage{
MRexperiment2biom(
  obj,
  id = NULL,
  norm = FALSE,
  log = FALSE,
  sl = 1000,
  qiimeVersion = TRUE
)
}
\arguments{
\item{obj}{The MRexperiment object.}

\item{id}{Optional id for the biom matrix.}

\item{norm}{normalize count table}

\item{log}{log2 transform count table}

\item{sl}{scaling factor for normalized counts.}

\item{qiimeVersion}{Format fData according to QIIME specifications (assumes only taxonomy in fData).}
}
\value{
A biom object.
}
\description{
Wrapper to convert MRexperiment objects to biom objects.
}
\seealso{
\code{\link{loadMeta}} \code{\link{loadPhenoData}} \code{\link{newMRexperiment}} \code{\link{loadBiom}} \code{\link{biom2MRexperiment}}
}
